package WWW::Mixi::Scraper::Plugin::NewMusic;
use strict;
use warnings;
use WWW::Mixi::Scraper::Plugin;

sub scrape { warn "This plugin is deprecated"; return [] }

1;

__END__

=head1 NAME

WWW::Mixi::Scraper::Plugin::NewMusic

=head1 DESCRIPTION

This plugin is deprecated.

=head1 METHOD

=head2 scrape

=head1 AUTHOR

Kenichi Ishigaki E<lt>ishigaki at cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kenichi Ishigaki.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
